@@ -16,7 +16,135 @@ class Delfipq(KaitaiStruct):
     :field rpt_callsign: ax25_frame.ax25_header.repeater.rpt_instance[0].rpt_callsign_raw.callsign_ror.callsign
     :field ctl: ax25_frame.ax25_header.ctl
     :field pid: ax25_frame.payload.pid
-    :field monitor: ax25_frame.payload.ax25_info.data_monitor
+    :field packet: ax25_frame.payload.ax25_info.packet
+    :field destination: ax25_frame.payload.ax25_info.delfipq.destination
+    :field size: ax25_frame.payload.ax25_info.delfipq.size
+    :field beacon_source: ax25_frame.payload.ax25_info.delfipq.beacon_source
+    :field service: ax25_frame.payload.ax25_info.delfipq.service
+    :field message_type: ax25_frame.payload.ax25_info.delfipq.message_type
+    :field message_outcome: ax25_frame.payload.ax25_info.delfipq.message_outcome
+    :field tlm_source: ax25_frame.payload.ax25_info.delfipq.tlm_source
+    :field pad: ax25_frame.payload.ax25_info.delfipq.telemetry_header.status.pad
+    :field software_image: ax25_frame.payload.ax25_info.delfipq.telemetry_header.status.software_image
+    :field boot_counter: ax25_frame.payload.ax25_info.delfipq.telemetry_header.boot_counter
+    :field soft_reset_wdt_timerexpiration: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.soft_reset_wdt_timerexpiration
+    :field cpu_lock_up: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.cpu_lock_up
+    :field por_power_settle: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.por_power_settle
+    :field por_clock_settle: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.por_clock_settle
+    :field voltage_anomaly: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.voltage_anomaly
+    :field hard_reset_wdt_wrong_password: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.hard_reset_wdt_wrong_password
+    :field hard_reset_wdt_timerexpiration: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.hard_reset_wdt_timerexpiration
+    :field system_reset_output: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.system_reset_output
+    :field sys_ctl_reboot: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.sys_ctl_reboot
+    :field nmi_pin: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.nmi_pin
+    :field exit_lpm4p5: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.exit_lpm4p5
+    :field exit_lpm3p5: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.exit_lpm3p5
+    :field bad_band_gap_reference: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.bad_band_gap_reference
+    :field supply_supervisor_vcc_trip: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.supply_supervisor_vcc_trip
+    :field vcc_detector_trip: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.vcc_detector_trip
+    :field soft_reset_wdt_wrong_password: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.soft_reset_wdt_wrong_password
+    :field padding: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.padding
+    :field dco_short_circuit_fault: ax25_frame.payload.ax25_info.delfipq.telemetry_header.reset_cause.dco_short_circuit_fault
+    :field uptime: ax25_frame.payload.ax25_info.delfipq.telemetry_header.uptime
+    :field total_uptime: ax25_frame.payload.ax25_info.delfipq.telemetry_header.total_uptime
+    :field tlm_version: ax25_frame.payload.ax25_info.delfipq.telemetry_header.tlm_version
+    :field mcu_temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mcu_temperature
+    :field ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.sensors_status.ina_status
+    :field tmp_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.sensors_status.tmp_status
+    :field telemetry_sensors_status_padding: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.sensors_status.padding
+    :field bus_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus_voltage
+    :field bus_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus_current
+    :field battery_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.battery_ina_status
+    :field battery_gg_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.battery_gg_status
+    :field internal_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.internal_ina_status
+    :field unregulated_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.unregulated_ina_status
+    :field bus1_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus1_ina_status
+    :field bus2_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus2_ina_status
+    :field bus3_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus3_ina_status
+    :field bus4_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus4_ina_status
+    :field bus4_error: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus4_error
+    :field bus3_error: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus3_error
+    :field bus2_error: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus2_error
+    :field bus1_error: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus1_error
+    :field bus4_state: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus4_state
+    :field bus3_state: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus3_state
+    :field bus2_state: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus2_state
+    :field bus1_state: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.bus1_state
+    :field panel_yp_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.panel_yp_ina_status
+    :field panel_ym_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.panel_ym_ina_status
+    :field panel_xp_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.panel_xp_ina_status
+    :field panel_xm_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.panel_xm_ina_status
+    :field panel_yp_tmp_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.panel_yp_tmp_status
+    :field panel_ym_tmp_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.panel_ym_tmp_status
+    :field panel_xp_tmp_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.panel_xp_tmp_status
+    :field panel_xm_tmp_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.panel_xm_tmp_status
+    :field mppt_yp_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.mppt_yp_ina_status
+    :field mppt_ym_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.mppt_ym_ina_status
+    :field mppt_xp_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.mppt_xp_ina_status
+    :field mppt_xm_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.mppt_xm_ina_status
+    :field cell_yp_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.cell_yp_ina_status
+    :field cell_ym_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.cell_ym_ina_status
+    :field cell_xp_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.cell_xp_ina_status
+    :field cell_xm_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.status.cell_xm_ina_status
+    :field internal_ina_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.internal_ina_current
+    :field internal_ina_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.internal_ina_voltage
+    :field unregulated_ina_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.unregulated_ina_current
+    :field unregulated_ina_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.unregulated_ina_voltage
+    :field battery_gg_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.battery_gg_voltage
+    :field battery_ina_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.battery_ina_voltage
+    :field battery_ina_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.battery_ina_current
+    :field battery_gg_capacity: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.battery_gg_capacity
+    :field battery_gg_temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.battery_gg_temperature
+    :field battery_tmp20_temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.battery_tmp20_temperature
+    :field bus4_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus4_current
+    :field bus3_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus3_current
+    :field bus2_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus2_current
+    :field bus1_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus1_current
+    :field bus4_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus4_voltage
+    :field bus3_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus3_voltage
+    :field bus2_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus2_voltage
+    :field bus1_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.bus1_voltage
+    :field panel_yp_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_yp_current
+    :field panel_ym_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_ym_current
+    :field panel_xp_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_xp_current
+    :field panel_xm_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_xm_current
+    :field panel_yp_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_yp_voltage
+    :field panel_ym_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_ym_voltage
+    :field panel_xp_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_xp_voltage
+    :field panel_xm_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_xm_voltage
+    :field panel_yp_temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_yp_temperature
+    :field panel_ym_temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_ym_temperature
+    :field panel_xp_temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_xp_temperature
+    :field panel_xm_temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.panel_xm_temperature
+    :field mppt_yp_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mppt_yp_current
+    :field mppt_ym_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mppt_ym_current
+    :field mppt_xp_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mppt_xp_current
+    :field mppt_xm_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mppt_xm_current
+    :field mppt_yp_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mppt_yp_voltage
+    :field mppt_ym_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mppt_ym_voltage
+    :field mppt_xp_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mppt_xp_voltage
+    :field mppt_xm_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.mppt_xm_voltage
+    :field cell_yp_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.cell_yp_current
+    :field cell_ym_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.cell_ym_current
+    :field cell_xp_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.cell_xp_current
+    :field cell_xm_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.cell_xm_current
+    :field cell_yp_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.cell_yp_voltage
+    :field cell_ym_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.cell_ym_voltage
+    :field cell_xp_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.cell_xp_voltage
+    :field current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.current
+    :field voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.voltage
+    :field temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.temperature
+    :field transmit_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.sensors_status.transmit_ina_status
+    :field amplifier_ina_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.sensors_status.amplifier_ina_status
+    :field phasing_tmp_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.sensors_status.phasing_tmp_status
+    :field amplifier_tmp_status: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.sensors_status.amplifier_tmp_status
+    :field receiver_rssi: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.receiver_rssi
+    :field transmit_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.transmit_voltage
+    :field transmit_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.transmit_current
+    :field amplifier_voltage: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.amplifier_voltage
+    :field amplifier_current: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.amplifier_current
+    :field phasing_board_temperature: ax25_frame.payload.ax25_info.delfipq.telemetry_header.telemetry.phasing_board_temperature
+    :field frametype: frametype
     """
     def __init__(self, _io, _parent=None, _root=None):
         self._io = _io
@@ -149,6 +277,8 @@ class Delfipq(KaitaiStruct):
 
         def _read(self):
             self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")
+            if not  ((self.callsign == u"GROUND") or (self.callsign == u"DLFIPQ")) :
+                raise kaitaistruct.ValidationNotAnyOfError(self.callsign, self._io, u"/types/callsign/seq/0")
 
 
     class Obctlmv2T(KaitaiStruct):
