@@ -355,8 +355,8 @@ class Geoscanedelveis(KaitaiStruct):
             self.obc_timestamp = self._io.read_u4le()
             self.eps_cell_current = self._io.read_u2le()
             self.eps_system_current = self._io.read_u2le()
-            self.eps_cell_voltage_half = self._io.read_u1()
-            self.eps_cell_voltage_full = self._io.read_u1()
+            self.eps_cell_voltage_half = self._io.read_u2le()
+            self.eps_cell_voltage_full = self._io.read_u2le()
             self.adc_temperature_pos_x = self._io.read_s1()
             self.adc_temperature_neg_x = self._io.read_s1()
             self.adc_temperature_pos_y = self._io.read_s1()
