@@ -308,10 +308,10 @@ class Oresat0(KaitaiStruct):
             self.c3_emmc_percent_full = self._io.read_u1()
             self.c3_l_rx_bytes_received = self._io.read_u4le()
             self.c3_l_rx_valid_packets = self._io.read_u4le()
-            self.c3_l_rx_rssi = self._io.read_u1()
+            self.c3_l_rx_rssi = self._io.read_s1()
             self.c3_uhf_rx_bytes_received = self._io.read_u4le()
             self.c3_uhf_rx_valid_packets = self._io.read_u4le()
-            self.c3_uhf_rx_rssi = self._io.read_u1()
+            self.c3_uhf_rx_rssi = self._io.read_s1()
             self.c3_fw_bank_current_and_next_bank = self._io.read_u1()
             self.c3_l_rx_sequence_number = self._io.read_u4le()
             self.c3_l_rx_rejected_packets = self._io.read_u4le()
