@@ -410,7 +410,7 @@ class Polyitan1(KaitaiStruct):
             self._read()
 
         def _read(self):
-            self.body = (self._io.read_bytes_term(0, False, True, True)).decode(u"ASCII")
+            self.body = (self._io.read_bytes_full()).decode(u"ASCII")
 
 
     class CallsignRaw(KaitaiStruct):
