@@ -2,7 +2,7 @@
 `pytest` testing framework file for Entrysat
 """
 
-import satnogsdecoders.decoder as decoder
+from satnogsdecoders import decoder
 from tests.shared_methods import check_type, load_objects
 
 
